#pragma once


/* pvc_image.h
 * 
 * 
 * Copyright (C) 2012 Ivo Ihrke
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */


#define PVC_IMAGE_ALIGNED_MEM    1
#define PVC_IMAGE_UNALIGNED_MEM  2



class PVC_Image_Gray
{

 protected:

  /*! allocate memory for data pointer */
  int alloc_mem( unsigned long int num_bytes, int mode = PVC_IMAGE_ALIGNED_MEM );
  int alignment_offset;


  /*! contains the image data */
  float *data;
  
  /*! private, contains width and height of the image */
  int    width, height;


 public:

  /*! constructor for empty image */
  PVC_Image_Gray();

  /*! constructor for zero image of given size */
  PVC_Image_Gray( int img_width, int img_height ); 

  /*! constructor from color image */
  PVC_Image_Gray( PVC_Image* colorImage);

  /*! destructor */
  ~PVC_Image_Gray();


  /*! allocate memory for resized image, remove old memory */
  int resize ( int img_width, int img_height, int mode = PVC_IMAGE_ALIGNED_MEM ); 

  /*! save image to disk */
  int save( const char *filename );

  /*! return image width */
  inline int w(){ return width; };

  /*! return image height */
  inline int h(){ return height; };

  /*! return data pointer */
  inline float* get_data(){ return data; };

  /*! normalize image to [0,1] */
  void normalize();

  /* pixel access */
  inline float get_value( int x, int y) {return data[ ( y*w() + x)];};
};


